======
vexmpp
======

XMPP library for Python3 asyncio.

Status
------
.. image:: https://img.shields.io/pypi/v/vexmpp.svg
   :target: https://pypi.python.org/pypi/vexmpp/
   :alt: Latest Version
.. image:: https://img.shields.io/pypi/status/vexmpp.svg
   :target: https://pypi.python.org/pypi/vexmpp/
   :alt: Project Status
.. image:: https://travis-ci.org/nicfit/vexmpp.svg?branch=master
   :target: https://travis-ci.org/nicfit/vexmpp
   :alt: Build Status
.. image:: https://img.shields.io/pypi/l/vexmpp.svg
   :target: https://pypi.python.org/pypi/vexmpp/
   :alt: License
.. image:: https://img.shields.io/pypi/pyversions/vexmpp.svg
   :target: https://pypi.python.org/pypi/vexmpp/
   :alt: Supported Python versions
.. image:: https://coveralls.io/repos/nicfit/vexmpp/badge.svg
   :target: https://coveralls.io/r/nicfit/vexmpp
   :alt: Coverage Status

Features
--------

* Free software: GNU GPL v3.0 license
